<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>ToggleGrid</name>
    <message>
        <location filename="../ToggleGrid.js" line="+90"/>
        <source>&amp;Grid</source>
        <translation>&amp;Mřížka</translation>
    </message>
</context>
</TS>
